@@ -5,12 +5,17 @@ using SymbolicAnalysis:
     getcurvature,
     getsign,
     getgcurvature
+
 using SafeTestsets, Test
 
 @testset "DCP" begin
     include("test.jl")
 end
 
-@testset "DGCP" begin
+@testset "DGCP - SPD Manifold" begin
     include("dgp.jl")
 end
+
+@testset "DGCP - Lorentz Manifold" begin
+    include("lorentz.jl")
+end
